@@ -164,7 +164,11 @@ gail_util_add_global_event_listener (GSignalEmissionHook listener,
         {
           rc = add_listener (listener, split_string[1], split_string[2], event_type);
         }
+
+      g_strfreev (split_string);
     }
+
+  g_free (split_string);
   return rc;
 }
 
@@ -485,12 +489,29 @@ window_removed (AtkObject *atk_obj,
                  AtkObject *child)
 {
   GtkWidget *widget;
+  GtkWindow *window;
 
   g_return_if_fail (GAIL_IS_WINDOW (child));
 
   widget = GTK_ACCESSIBLE (child)->widget;
   g_return_if_fail (widget);
 
+  window = GTK_WINDOW (widget);
+  /*
+   * Deactivate window if it is still focused and we are removing it. This
+   * can happen when a dialog displayed by gok is removed.
+   */
+  if (window->is_active &&
+      window->has_toplevel_focus)
+    {
+      gchar *signal_name;
+      AtkObject *atk_obj;
+
+      atk_obj = gtk_widget_get_accessible (widget);
+      signal_name =  "deactivate";
+      g_signal_emit (atk_obj, g_signal_lookup (signal_name, GAIL_TYPE_WINDOW), 0); 
+    }
+
   g_signal_handlers_disconnect_by_func (widget, (gpointer) window_focus, NULL);
   g_signal_emit (child, g_signal_lookup ("destroy", GAIL_TYPE_WINDOW), 0); 
 }
@@ -502,7 +523,7 @@ window_focus (GtkWidget     *widget,
   gchar *signal_name;
   AtkObject *atk_obj;
 
-  g_return_val_if_fail (GTK_WIDGET (widget), FALSE);
+  g_return_val_if_fail (GTK_IS_WIDGET (widget), FALSE);
 
   atk_obj = gtk_widget_get_accessible (widget);
   signal_name =  (event->in) ? "activate" : "deactivate";
@@ -547,7 +568,15 @@ configure_event_watcher (GSignalInvocationHint  *hint,
       widget->allocation.height == ((GdkEventConfigure *)event)->height)
     return TRUE;
 
-  signal_name = "resize";
+  if (widget->allocation.width != ((GdkEventConfigure *)event)->width ||
+      widget->allocation.height != ((GdkEventConfigure *)event)->height)
+    {
+      signal_name = "resize";
+    }
+  else
+    {
+      signal_name = "move";
+    }
 
   atk_obj = gtk_widget_get_accessible (widget);
   g_return_val_if_fail (GAIL_IS_WINDOW (atk_obj), FALSE);
